@@ -1,12 +1,13 @@
 """Define isbntools API and set lib environment."""
 
-__all__ = ('is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
+__all__ = ('ISBNToolsException',
+           'is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'to_isbn10', 'to_isbn13', 'get_isbnlike', 'notisbn', 'EAN13',
            'canonical', 'get_canonical_isbn', 'editions', 'isbn_from_words',
            'quiet_errors', 'config', 'setconf', '__version__', '__support__',
            'doi', 'check_version', 'ISBN13', 'Cache', 'in_virtual')
 
-__version__ = '3.3.6'                               # <-- literal IDs
+__version__ = '3.3.7'                               # <-- literal IDs
 __support__ = 'py26, py27, py33, py34, pypy'        # <-- literal IDs
 
 
@@ -23,7 +24,7 @@ def in_virtual():
 from . import config        # <-- first import
 from . import setconf       # <-- first import
 from ._version import check_version
-from .exceptions import quiet_errors
+from ._exceptions import quiet_errors, ISBNToolsException
 
 
 pkg_path = _os.path.dirname(_os.path.abspath(__file__))
