@@ -7,9 +7,9 @@ from isbntools.dev.webquery import query as wquery
 from isbntools.dev import stdmeta
 from isbntools.dev.bouth23 import u
 from isbntools.config import apikeys
-from isbntools.dev.exceptions import (DataWrongShapeError,
-                                      NoDataForSelectorError,
-                                      RecordMappingError, NoAPIKeyError)
+from isbntools.dev._exceptions import (DataWrongShapeError,
+                                       NoDataForSelectorError,
+                                       RecordMappingError, NoAPIKeyError)
 
 
 UA = 'isbntools (gzip)'
