@@ -5,8 +5,8 @@ import logging
 from isbntools.dev.webquery import query as wquery
 from isbntools.dev import stdmeta
 from isbntools.dev.bouth23 import u
-from isbntools.dev.exceptions import (NoDataForSelectorError,
-                                      RecordMappingError)
+from isbntools.dev._exceptions import (NoDataForSelectorError,
+                                       RecordMappingError)
 
 
 UA = 'isbntools (gzip)'
