@@ -11,7 +11,7 @@ try:                     # pragma: no cover
 except ImportError:      # pragma: no cover
     from urllib import urlencode
     from urllib2 import Request, urlopen, HTTPError, URLError
-from .exceptions import ISBNToolsHTTPError, ISBNToolsURLError
+from ._exceptions import ISBNToolsHTTPError, ISBNToolsURLError
 
 UA = 'webservice (gzip)'
 LOGGER = logging.getLogger(__name__)
@@ -21,11 +21,14 @@ class WEBService(object):
 
     """Class to query web services."""
 
-    def __init__(self, url, user_agent=UA, values=None):
+    def __init__(self, url, user_agent=UA, values=None, appheaders=None):
         """Initialize main properties."""
         self._url = url
         # headers to accept gzipped content
         headers = {'Accept-Encoding': 'gzip', 'User-Agent': user_agent}
+        # add more user provided headers
+        if appheaders is not None:
+            headers.update(appheaders)
         # if 'data' it does a PUT request (data must be urlencoded)
         data = urlencode(values) if values else None
         self._request = Request(url, data, headers=headers)
@@ -34,6 +37,7 @@ class WEBService(object):
     def _response(self):
         try:
             self.response = urlopen(self._request)
+            LOGGER.debug('Request headers:\n%s', self._request.header_items())
         except HTTPError as e:  # pragma: no cover
             LOGGER.critical('ISBNToolsHTTPError for %s with code %s',
                             self._url, e.code)
@@ -46,6 +50,7 @@ class WEBService(object):
     def data(self):
         """Return the uncompressed data."""
         self._response()
+        LOGGER.debug('Response headers:\n%s', self.response.info())
         if self.response.info().get('Content-Encoding') == 'gzip':
             buf = bstream(self.response.read())
             f = gzip.GzipFile(fileobj=buf)
@@ -58,4 +63,6 @@ class WEBService(object):
 def query(url, user_agent=UA, values=None):
     """Query to a web service."""
     service = WEBService(url, user_agent, values)
-    return service.data()
+    data = service.data()
+    LOGGER.debug('Raw data from service:\n%s', data)
+    return data
